
# -*- coding: utf-8 -*-

"""
1分ごとに、以下の挙動を行う。

1. X時 Y分 00sになったら、X時の個所まで回転し、0時の所まで戻ってくる
2. 1の回転終了後、Y分の個所まで回転し、それまでに経過した秒針の所まで戻ってくる
3. 以降、2までに経過した秒針から1秒単位で回転し、60秒まで進む

※ Buildtのローター回転部にネジやテープ等の目印があると確認しやすい

"""

from time import sleep                          # timeライブラリからsleep関数を読み込む
from datetime import datetime                   # datetimeライブラリからdatetime関数を読み込む
from pybuildit import *                         # Builditを操作するためのpybuilditライブラリを読み込む
import threading                                # threadingライブラリを読み込む

def wait_keybord_input():                       # 任意のキー入力で終了
    global stop_move                            # stop_move をグローバル変数にする
    input()                                     # キーボード入力を待つ
    stop_move = True                            # stop_move変数値をTrueにする
    print("Stop")                               # Stop文字列を出力

SLEEP_TIME = 0.1                                            # 次サンプリングまでの待機時間[s]
DISP_WAIT = 1                                               # 表示に用いる待機時間 [s]
DEVICE_ID = 1                                               # このプログラム内で扱うBuilditのIDを"1"とする
PORT = "COM5"                                               # 環境に合わせて変更してください

buildit = Buildit(port=PORT)                                # Builditと接続する
stop_move = False                                           # stop_move変数値をFalseにする

threading.Thread(target=wait_keybord_input).start()         # 複数のタスクを同時に実行する(wait_keyboard_input関数)

buildit.force_ready(DEVICE_ID)                              # IDが"1"のBuilditをhold状態にする
buildit.free(DEVICE_ID)                                     # IDが"1"のBuilditをfree状態にする(ブレーキ解除)
buildit.reset_rotation(DEVICE_ID)                           # Buildit 1 が何回転しているかを変更します。 
buildit.ready(DEVICE_ID)                                    # IDが"1"のBuilditをhold状態にする

prev = None                                                 # prev変数値をNoneにする

while not stop_move:                                        # stop_move=Falseの間にループを実行する

    now = datetime.now()                                                # 現在の時間を受け取る

    if now == prev:                                                     # もし now == prev なら　
        sleep(SLEEP_TIME)                                               # SLEEP_TIME値秒待つ
    else:
        prev = now                                                      # prev変数値をnowにする
        
    if now.second == 0:                                                 # もしnow変数の秒値は0なら         
        # 時を表示
        ref_deg = - (now.hour % 12) * 30                                # Buildit は半時計回りが正方向
        buildit.set_ref_position(DEVICE_ID, from_deg(ref_deg))          # buildit1 の位置を　ref_degにセットする
        buildit.wait_until_stop_at(DEVICE_ID, from_deg(ref_deg), 1000)  # Buildit 1 の回転が終了するのを待つ
        sleep(DISP_WAIT)                                                # DISP_WAIT値秒待つ    

        # 分を表示
        ref_deg = - now.minute * 6
        buildit.set_ref_position(DEVICE_ID, from_deg(ref_deg))          # buildit1 の位置を　ref_degにセットする
        buildit.wait_until_stop_at(DEVICE_ID, from_deg(ref_deg), 1000)  # Buildit 1 の回転が終了するのを待つ
        sleep(DISP_WAIT)                                                # DISP_WAIT値秒待つ

    else:
        # 秒を表示
        ref_deg = - now.second * 6
        buildit.set_ref_position(DEVICE_ID, from_deg(ref_deg))          # buildit1 の位置を　ref_degにセットする

buildit.stop(DEVICE_ID)                                     # Builditを停止する          
buildit.hold(DEVICE_ID)                                     # IDが"1"のBuilditをhold状態にする

buildit.close()                                             # 接続していたBuilditを切断する




