# -*- coding: utf-8 -*-

"""
2台のデイジーチェーン接続されたBuilditを、現在の時間や指定の時間にあわせてBuildit1（時）とBuildit2（分）を回転させるプログラム
※Builditの各種設定値は初期値とする
# 使い方： 現在の時間 --> python clock_show_buildit.py   # 指定の時間の場合 ex: 09:00 --> python clock_show_buildit.py 09 00 
"""

import time
from time import sleep                                      # timeライブラリからsleep関数を読み込む
from pybuildit import *                                     # Builditを操作するためのpybuilditライブラリを読み込む
import sys                                                  # sysライブラリを読み込む
from datetime import datetime                               # datetimeライブラリからdatetime関数を読み込む

PORT = "COM5"                                               # 環境に合わせて変更してください
DEVICE_ID_1 = 1                                             # 1つめのBuilditのIDを"1"とする
DEVICE_ID_2 = 2                                             # 2つめのBuilditのIDを"2"とする

buildit = Buildit(port = PORT)                                # Builditと接続する

buildit.force_ready(DEVICE_ID_1)                            # Buildit 1 を制御待ち状態にする
buildit.force_ready(DEVICE_ID_2)                            # Buildit 2 を制御待ち状態にする

buildit.set_ref_position(DEVICE_ID_1, from_deg(0))          # Buildit 1 を0度まで回転させ始める
buildit.set_ref_position(DEVICE_ID_2, from_deg(0))          # Buildit 2 を0度まで回転させ始める

buildit.wait_until_stop_at(DEVICE_ID_1, from_deg(0), 1000)  # Buildit 1 の回転が終了するのを待つ
buildit.wait_until_stop_at(DEVICE_ID_2, from_deg(0), 1000)  # Buildit 2 の回転が終了するのを待つ

def time_show(a, b):                                         # 時間によって位置を計算する関数 
    pos_1 = 360 -(a*30 +b/2)                                # buildit1 の位置を計算してpos_1にアサインする
    pos_2 = 360-(b*6)                                       # buildit2 の位置を計算してpos_2にアサインする
    print("POS1: {}\t POS2: {}".format(pos_1, pos_2))
    buildit.set_ref_position(DEVICE_ID_1, from_deg(pos_1))  # buildit1 の位置を　pos_1にセットする
    buildit.set_ref_position(DEVICE_ID_2, from_deg(pos_2))  # buildit2 の位置を　pos_2にセットする　

def main():                                                 # Main プログラムの関数
    current_time = datetime.now()                           # 現在の時間を受け取る

    if len(sys.argv) < 2:                                    # もしスクリプトを実装する時別の引数は入力されていないと
        time_show(current_time.hour, current_time.minute)   # 現在の時間の時を引数１にして分を引数2にしてtime_showの関数を実装
        print("current time: {}:{}".format(current_time.hour, current_time.minute))

    elif len(sys.argv) == 3:                                # もしスクリプトを実装する時二つのの引数は入力されていると
        hour = int(sys.argv[1])                             # 入力し一つ目の引数を時にする
        minute = int(sys.argv[2])                           # 入力し二つ目の引数を分にする
        time_show(hour, minute)                             # hourを引数１にしてminuteを引数2にして　time_showの関数を実装
        print("time: {}:{}".format(hour, minute)) 
    else:
        print("unknown arguments")
        
main()                                                      # メインプログラムを実装する


