# -*- coding: utf-8 -*-

"""
単一のBuilditをブレーキ解除状態で動かした動作を記憶させ、その動作を再現する
シリアル通信のレイテンシを1ms程度にすること
"""

from pybuildit import *
from time import sleep
import threading

def wait_keybord_input(): # 任意のキー入力で学習終了
    global stop_recording
    input()
    stop_recording = True
    print("Stop recording")


SLEEP_TIME = 0.003 # 次サンプリングまでの待機時間[s]
DEVICE_ID = 1
PORT = "/dev/ttyUSB0"

buildit = Buildit(port=PORT)
records = []
stop_recording = False

threading.Thread(target=wait_keybord_input).start()

buildit.force_ready(DEVICE_ID)
buildit.free(DEVICE_ID) # ブレーキ解除
buildit.reset_rotation(DEVICE_ID)

print("Start recording...")

while not stop_recording:
    records.append(buildit.query_servo_status(DEVICE_ID).position()) # 現在の位置情報を記憶
    sleep(SLEEP_TIME)

sleep(1)

print("Move to start position")

# 動作の初期位置へ移動
buildit.reset_rotation(DEVICE_ID)
buildit.ready(DEVICE_ID)
buildit.set_ref_position(DEVICE_ID, records[0])

# 移動完了を待つ
buildit.wait_until_stop_at(DEVICE_ID, records[0], 1000)

print("Start replay")

for pos in records:
    buildit.set_ref_position(DEVICE_ID, pos)
    sleep(SLEEP_TIME)

print("done")
