# -*- coding: utf-8 -*-

"""
複数のBuilditをブレーキ解除状態で動かした動作を記憶させ、その動作を再現する
シリアル通信のレイテンシを1ms程度にすること
"""

from pybuildit import *
from time import sleep
import threading


def wait_until_stop_at(buildit, dev_id, pos, thres=10):
    def has_stopped(state, qssr):
        return abs(qssr.position() - pos) <= thres and state != STATE_FAULT_HOLD
    buildit.wait_until(dev_id, has_stopped)


def wait_keybord_input(): # 任意のキー入力で学習終了
    global stop_recording
    input()
    stop_recording = True
    print("Stop recording")


SLEEP_TIME = 0.001 # 次サンプリングまでの待機時間[s]
DEVICE_ID_LIST = [1, 2] # 記憶・操作するデバイスIDのリスト
PORT = "/dev/ttyUSB0"

buildit = Buildit(port=PORT)
records = []
stop_recording = False

threading.Thread(target=wait_keybord_input).start() # 別スレッドでキー入力を待つ

for dev_id in DEVICE_ID_LIST:
    buildit.force_ready(dev_id)
    buildit.free(dev_id) # ブレーキ解除
    buildit.reset_rotation(dev_id)

print("Start recording...")

while not stop_recording:
    records.append([buildit.query_servo_status(dev_id).position() for dev_id in DEVICE_ID_LIST]) # 現在の位置情報を記憶
    sleep(SLEEP_TIME)

sleep(1)

print("Move to start position...")

# 動作の初期位置へ移動
for i, dev_id in enumerate(DEVICE_ID_LIST):
    buildit.reset_rotation(dev_id)
    buildit.ready(dev_id)
    buildit.set_ref_position(dev_id, records[0][i])

# 移動完了を待つ
for i, dev_id in enumerate(DEVICE_ID_LIST):
    buildit.wait_until_stop_at(dev_id, records[0][i], 1000)

print("Start replay")

for pos_list in records:
    for i, dev_id in enumerate(DEVICE_ID_LIST):
        buildit.set_ref_position(dev_id, pos_list[i])
    sleep(SLEEP_TIME)

print("done")
