# -*- coding: utf-8 -*-

"""
Builditを10RPMで回転させ、5秒おきに回転方向を反転させるプログラム
ただし回転方向を反転する際3秒間停止する

ポイント
* set_ref_velocityは速度制御の開始をBuilditに指示するだけで、指定した速度になるまで待つことはしません。
* Builditがある状態になるまで待つにはwait_until関数を使います。
"""

from time import sleep                                  # timeライブラリからsleep関数を読み込む
from pybuildit import *                                 # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                           # 環境に合わせて変更してください
DEVICE_ID = 1                                           # このプログラム内で扱うBuilditのIDを"1"とする

def wait_until_stop(buildit, dev_id, vel, thres=10):    # 回転速度がvel ± thresになるまで待つ関数
    def has_stopped(state, qssr):
        return abs(qssr.velocity() - vel) <= thres and state != STATE_FAULT_HOLD
    buildit.wait_until(dev_id, has_stopped)

direction = 1                                                       # 回転方向、1:正回転, -1:逆回転

buildit = Buildit(port=PORT)                                        # Builditと接続する
buildit.force_ready(DEVICE_ID)                                      # Builditを制御待ち状態にする

for i in range(4):                                                  # 4回繰り返す
    buildit.set_ref_velocity(DEVICE_ID, direction * from_rpm(10))   # 10RPMもしくは-10RPMで回転させ始める

    sleep(5)                                                        # 5秒間待つ

    buildit.stop(DEVICE_ID)                                         # 回転を停止(速度を0)にする
    wait_until_stop(buildit, DEVICE_ID, 0, 0.05)                    # 回転速度が0±0.05になるまで待つ

    sleep(3)                                                        # 3秒間待つ

    direction = direction * -1                                      # 回転方向を逆転

buildit.stop(DEVICE_ID)                                             # Builditを停止する

buildit.close()                                                     # Builditとの接続を切断する






