# -*- coding: utf-8 -*-

"""
2台のBuilditを10RPMで回転させ、5秒おきに回転方向を反転させるプログラム
ただし回転方向を反転する際3秒間停止する

ポイント
* 複数のBuilditの状態をwait_untilで待つ場合はwait_untilをBuilditの台数分使用します。
"""

from time import sleep                                  # timeライブラリからsleep関数を読み込む
from pybuildit import *                                 # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                           # 環境に合わせて変更してください
DEVICE_ID_1 = 1                                         # 1つめのBuilditのIDを"1"とする
DEVICE_ID_2 = 2                                         # 2つめのBuilditのIDを"2"とする

def wait_until_stop(buildit, dev_id, vel, thres=0.05):              # 回転速度がvel ± thresになるまで待つ関数
    def has_stopped(state, qssr):
        return abs(qssr.velocity() - vel) <= thres and state != STATE_FAULT_HOLD
    buildit.wait_until(dev_id, has_stopped)

direction = 1                                                       # 回転方向、1:正回転, -1:逆回転

buildit = Buildit(port=PORT)                                        # Builditと接続する
buildit.force_ready(DEVICE_ID_1)                                    # Builditを制御待ち状態にする
buildit.force_ready(DEVICE_ID_2)                                    # Builditを制御待ち状態にする

for i in range(4):                                                  # 4回繰り返す
    buildit.set_ref_velocity(DEVICE_ID_1, direction * from_rpm(10)) # 10RPMもしくは-10RPMで回転させ始める
    buildit.set_ref_velocity(DEVICE_ID_2, direction * from_rpm(10)) # 10RPMもしくは-10RPMで回転させ始める

    sleep(5)                                                        # 5秒間待つ

    buildit.stop(DEVICE_ID_1)                                       # 回転を停止する
    buildit.stop(DEVICE_ID_2)                                       # 回転を停止する
    wait_until_stop(buildit, DEVICE_ID_1, 0, 0.05)                  # 回転速度が0±0.05になるまで待つ
    wait_until_stop(buildit, DEVICE_ID_2, 0, 0.05)                  # 回転速度が0±0.05になるまで待つ

    sleep(3)                                                        # 3秒間待つ

    direction = direction * -1                                      # 回転方向を逆転

buildit.stop(DEVICE_ID_1)                                           # Builditを停止する
buildit.stop(DEVICE_ID_2)                                           # Builditを停止する

buildit.close()                                                     # Builditとの接続を切断する



