# -*- coding: utf-8 -*-

"""
Builditのロータを現在の位置から位置制御によって90度回転させるプログラム

ポイント
* set_ref_position関数を使うことで、Builditに位置制御を指示することができます。
* Builditの状態を取得するにはquery_servo_status()関数を使用します。
* query_servo_status()関数はBuilditの状態を格納したオブジェクトを返します。各情報を取得するメソッドは以下の通りです。
 - position() 現在の位置
 - velocity() 現在の速度
 - current() 現在の電流
 - ref() 現在の指令値
 - temperature() 現在の温度
 - faults() 現在発生しているフォルト
"""

from time import sleep                              # timeライブラリからsleep関数を読み込む
from pybuildit import *                             # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                       # 環境に合わせて変更してください
DEVICE_ID = 1                                       # このプログラム内で扱うBuilditのIDを"1"とする

buildit = Buildit(port=PORT)                        # Builditと接続する
buildit.force_ready(DEVICE_ID)                      # Builditを制御待ち状態にする

current_position = buildit.query_servo_status(DEVICE_ID).position()     # 現在の位置(角度)を取得する
buildit.set_ref_position(DEVICE_ID, current_position + from_deg(90))    # 位置制御によって"現在の位置+90度"の
                                                                        # 位置にむけて回転させ始める

buildit.close()                                                         # Builditとの接続を切断する






