# -*- coding: utf-8 -*-

"""
Builditを360度以上時計・反時計回りに回転させて現在の位置を表示するプログラム

ポイント
* 位置制御は多回転に対応しています。位置制御で90度の次に450度を指定すると、Builditは1回転します。
* 何回転したかの情報はBuilditの電源がオフになると消去されます。
"""

from time import sleep                                  # timeライブラリからsleep関数を読み込む
from pybuildit import *                                 # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                                   # 環境に合わせて変更してください
DEVICE_ID = 1                                                   # このプログラム内で扱うBuilditのIDを"1"とする
POSITION_LIST = [0, 90, 450, 810, -270]                         # 回転させる位置のリスト

buildit = Buildit(port=PORT)                                    # Builditと接続する
buildit.force_ready(DEVICE_ID)                                  # Builditを制御待ち状態にする
buildit.hold(DEVICE_ID)                                         # 一度ブレーキをかける
buildit.reset_rotation(DEVICE_ID)                               # 回転数をリセットする
buildit.ready(DEVICE_ID)                                        # Builditを制御待ち状態にする

for pos in POSITION_LIST:
    print("move to: ", pos)
    buildit.set_ref_position(DEVICE_ID, from_deg(pos))          # Buildit を90度まで回転させ始める
    buildit.wait_until_stop_at(DEVICE_ID, from_deg(pos), 1000)  # Buildit の回転が終了するのを待つ
    print("position: ", pos)
    sleep(1)

buildit.stop(DEVICE_ID)                                         # Buildit を停止する

buildit.close()                                                 # Builditとの接続を切断する






