# -*- coding: utf-8 -*-

"""
Builditを0度から90度まで20[RPM]以下で2往復させるプログラム

ポイント
* 位置制御をする際に速度制限を設定しておくと、制限された範囲内の速度で位置制御を行います。
* 速度制限の設定は、電源をオフにしてもBuildit内に保存されます。プログラムが中断された場合は再設定が必要かご確認下さい。
"""

from time import sleep                                  # timeライブラリからsleep関数を読み込む
from pybuildit import *                                 # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                           # 環境に合わせて変更してください
DEVICE_ID = 1                                           # このプログラム内で扱うBuilditのIDを"1"とする

buildit = Buildit(port=PORT)                            # Builditと接続する
buildit.force_ready(DEVICE_ID)                          # Builditを制御待ち状態にする

buildit.set_ref_position(DEVICE_ID, from_deg(0))                    # Buildit を0度まで回転させ始める
buildit.wait_until_stop_at(DEVICE_ID, from_deg(0), 1000)            # Buildit の回転が終了するのを待つ

max_limit = buildit.get_velocity_max_limit(DEVICE_ID)               # 現在の最大速度リミット値
min_limit = buildit.get_velocity_min_limit(DEVICE_ID)               # 現在の最小速度リミット値

print(min_limit, max_limit)

buildit.set_velocity_max_limit(DEVICE_ID, from_rpm(20))             # 正方向に20[RPM]以下に制限
buildit.set_velocity_min_limit(DEVICE_ID, from_rpm(-20))            # 負方向に20[RPM]以下に制限

for i in range(2):
    buildit.set_ref_position(DEVICE_ID, from_deg(90))               # Buildit を90度まで回転させ始める
    buildit.wait_until_stop_at(DEVICE_ID, from_deg(90), 1000)       # Buildit の回転が終了するのを待つ

    sleep(1)

    buildit.set_ref_position(DEVICE_ID, from_deg(0))                # Buildit を0度まで回転させ始める
    buildit.wait_until_stop_at(DEVICE_ID, from_deg(0), 1000)        # Buildit の回転が終了するのを待つ

    sleep(1)

buildit.set_velocity_max_limit(DEVICE_ID, max_limit)                # 最大速度制限解除
buildit.set_velocity_min_limit(DEVICE_ID, min_limit)                # 最小速度制限解除

buildit.stop(DEVICE_ID)                                             # Buildit を停止する
buildit.hold(DEVICE_ID)                                             # Buildit をブレーキをON

buildit.close()                                                     # Builditとの接続を切断する




