# -*- coding: utf-8 -*-

"""
Builditを0度から90度まで60秒間往復させるプログラム
"""

import time                                             # time 関数を使用するためにtimeライブラリを読み込む
from pybuildit import *                                 # Builditを操作するためのpybuilditライブラリを読み込む

def wait_until_stop_at(buildit, dev_id, pos, thres=10):
    def has_stopped(state, qssr):
        return abs(qssr.position() - pos) <= thres and state != STATE_FAULT_HOLD
    buildit.wait_until(dev_id, has_stopped)

PORT = "COM5"                                               # 環境に合わせて変更してください
DEVICE_ID = 1                                               # このプログラム内で扱うBuilditのIDを"1"とする
PERIOD = 60                                                 # 往復させ続ける時間

buildit = Buildit(port=PORT)                                # Builditと接続する
buildit.force_ready(DEVICE_ID)                              # Builditを制御待ち状態にする

buildit.set_ref_position(DEVICE_ID, from_deg(0))            # Buildit を0度まで回転させ始める
wait_until_stop_at(buildit, DEVICE_ID, from_deg(0))         # Buildit の回転が終了するのを待つ

t0 = time.time()

while time.time() < t0 + PERIOD:
    buildit.set_ref_position(DEVICE_ID, from_deg(90))       # Buildit を90度まで回転させ始める
    wait_until_stop_at(buildit, DEVICE_ID, from_deg(90))    # Buildit の回転が終了するのを待つ

    buildit.set_ref_position(DEVICE_ID, from_deg(0))        # Buildit を0度まで回転させ始める
    wait_until_stop_at(buildit, DEVICE_ID, from_deg(0))     # Buildit の回転が終了するのを待つ

buildit.stop(DEVICE_ID)                                     # Buildit を停止する

buildit.close()                                             # Builditとの接続を切断する





