# -*- coding: utf-8 -*-

"""
Builditを電流1000で５秒間回転させるプログラム

ポイント
* set_ref_current関数を使うことで、Builditに電流制御を指示することができます。
* set_ref_current関数への電流の指示は-5000〜5000の間で可能です。
  5000が正回転の方向に100%の電流、-5000が逆回転の方向に100%の電流を意味します。
"""

from time import sleep                       # timeライブラリからsleep関数を読み込む
from pybuildit import *                      # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                # 環境に合わせて変更してください
DEVICE_ID = 1                                # このプログラム内で扱うBuilditのIDを"1"とする

buildit = Buildit(port=PORT)                 # Builditと接続する

buildit.force_ready(DEVICE_ID)               # Builditを制御待ち状態にする

buildit.set_ref_current(DEVICE_ID, 1000)     # Builditを電流指令値1000で回転させ始める(単位はおおよそ[mA]に相当)

sleep(5)                                     # 5秒間待つ

buildit.stop(DEVICE_ID)                      # Builditを停止する

buildit.close()                              # Builditとの接続を切断する




