# -*- coding: utf-8 -*-

"""
Builditを電流制御で回転させるプログラム
3秒毎に電流指令値を上昇させる

ポイント
* 電流指令値が上昇するごとにBuilditが発揮するトルクが増加します。
"""

from time import sleep                              # timeライブラリからsleep関数を読み込む
from pybuildit import *                             # Builditを操作するためのpybuilditライブラリを読み込む


PORT = "COM5"                                       # 環境に合わせて変更してください
DEVICE_ID = 1                                       # このプログラム内で扱うBuilditのIDを"1"とする
CUR_REF_LIST = [1000, 1500, 2000]                   # 使用する指令値のリスト

buildit = Buildit(port=PORT)                        # Builditと接続する

buildit.force_ready(DEVICE_ID)                      # Builditを制御待ち状態にする

for ref in CUR_REF_LIST:
    print("ref:", ref)
    buildit.set_ref_current(DEVICE_ID, ref)         # Builditを電流指令値refで回転させ始める
    sleep(3)                                        # 3秒間待つ

buildit.stop(DEVICE_ID)                             # Builditを停止する

buildit.close()                                     # Builditとの接続を切断する





