# -*- coding: utf-8 -*-
"""
2台のデイジーチェーン接続されたBuilditを0度から90度まで30rpmの速度で10往復させるプログラム
"""

from time import sleep                                    # timeライブラリからsleep関数を読み込む
from pybuildit import *                                   # Builditを操作するためのpybuilditライブラリを読み込む

PORT = "COM5"                                             # 環境に合わせて変更してください
DEVICE_ID_1 = 1                                           # 1つめのBuilditのIDを"1"とする
DEVICE_ID_2 = 2                                           # 2つめのBuilditのIDを"2"とする

buildit = Buildit(port=PORT)                              # Builditと接続する

buildit.force_ready(DEVICE_ID_1)                          # Buildit 1 を制御待ち状態にする
buildit.force_ready(DEVICE_ID_2)                          # Buildit 2 を制御待ち状態にする

buildit.set_ref_position(DEVICE_ID_1, from_deg(0))                  # Buildit 1 を0度まで回転させ始める
buildit.set_ref_position(DEVICE_ID_2, from_deg(0))                  # Buildit 2 を0度まで回転させ始める

buildit.wait_until_stop_at(DEVICE_ID_1, from_deg(0), 1000)          # Buildit 1 の回転が終了するのを待つ
buildit.wait_until_stop_at(DEVICE_ID_2, from_deg(0), 1000)          # Buildit 2 の回転が終了するのを待つ

# 現在の最大速度リミット値と最小速度リミット値を受け取る
vel_max_1 = buildit.get_velocity_max_limit(DEVICE_ID_1)             # Buildit1の現在の最大速度リミット値
vel_max_2 = buildit.get_velocity_max_limit(DEVICE_ID_2)             # Buildit2の現在の最大速度リミット値
vel_min_1 = buildit.get_velocity_min_limit(DEVICE_ID_1)             # Buildit1の現在の最小速度リミット値
vel_min_2 = buildit.get_velocity_min_limit(DEVICE_ID_2)             # Buildit2の現在の最小速度リミット値

# Builditの正方向に30[RPM]、負方向に30[RPM]以下に制限する
buildit.set_velocity_max_limit(DEVICE_ID_1, from_rpm(30))           # Buildit1の正方向に30[RPM]以下に制限
buildit.set_velocity_max_limit(DEVICE_ID_2, from_rpm(30))           # Buildit2の正方向に30[RPM]以下に制限
buildit.set_velocity_min_limit(DEVICE_ID_1, from_rpm(-30))          # Buildit1の負方向に30[RPM]以下に制限
buildit.set_velocity_min_limit(DEVICE_ID_2, from_rpm(-30))          # Buildit2の負方向に30[RPM]以下に制限

for i in range(10):
    buildit.set_ref_position(DEVICE_ID_1, from_deg(90))             # Buildit 1 を90度まで回転させ始める
    buildit.set_ref_position(DEVICE_ID_2, from_deg(90))             # Buildit 2 を90度まで回転させ始める

    buildit.wait_until_stop_at(DEVICE_ID_1, from_deg(90), 1000)     # Buildit 1 の回転が終了するのを待つ
    buildit.wait_until_stop_at(DEVICE_ID_2, from_deg(90), 1000)     # Buildit 2 の回転が終了するのを待つ

    buildit.set_ref_position(DEVICE_ID_1, from_deg(0))              # Buildit 1 を0度まで回転させ始める
    buildit.set_ref_position(DEVICE_ID_2, from_deg(0))              # Buildit 2 を0度まで回転させ始める

    buildit.wait_until_stop_at(DEVICE_ID_1, from_deg(0), 1000)      # Buildit 1 の回転が終了するのを待つ
    buildit.wait_until_stop_at(DEVICE_ID_2, from_deg(0), 1000)      # Buildit 2 の回転が終了するのを待つ

# Builditの最大速度と小速度制限解除
buildit.set_velocity_max_limit(DEVICE_ID_1, vel_max_1)              # Buildit1の最大速度制限解除
buildit.set_velocity_max_limit(DEVICE_ID_2, vel_max_2)              # Buildit2の最大速度制限解除
buildit.set_velocity_min_limit(DEVICE_ID_1, vel_min_1)              # Buildit1の最小速度制限解除
buildit.set_velocity_min_limit(DEVICE_ID_2, vel_min_2)              # Buildit2の最小速度制限解除

buildit.stop(DEVICE_ID_1)                               # Buildit 1 を停止する
buildit.stop(DEVICE_ID_2)                               # Buildit 2 を停止する

buildit.hold(DEVICE_ID_1)                               # Buildit 1 をブレーキをON
buildit.hold(DEVICE_ID_2)                               # Buildit 2 をブレーキをON

buildit.close()                                         # Builditとの接続を切断する




